mathtools
=========

.. automodule:: abjad.tools.mathtools

.. only:: html

   Concrete classes
   ----------------

   .. autosummary::

      ~abjad.tools.mathtools.BoundedObject.BoundedObject
      ~abjad.tools.mathtools.Infinity.Infinity
      ~abjad.tools.mathtools.NegativeInfinity.NegativeInfinity
      ~abjad.tools.mathtools.NonreducedFraction.NonreducedFraction
      ~abjad.tools.mathtools.NonreducedRatio.NonreducedRatio
      ~abjad.tools.mathtools.Ratio.Ratio

   Functions
   ---------

   .. autosummary::

      ~abjad.tools.mathtools.are_relatively_prime.are_relatively_prime
      ~abjad.tools.mathtools.arithmetic_mean.arithmetic_mean
      ~abjad.tools.mathtools.binomial_coefficient.binomial_coefficient
      ~abjad.tools.mathtools.cumulative_products.cumulative_products
      ~abjad.tools.mathtools.cumulative_signed_weights.cumulative_signed_weights
      ~abjad.tools.mathtools.cumulative_sums.cumulative_sums
      ~abjad.tools.mathtools.cumulative_sums_pairwise.cumulative_sums_pairwise
      ~abjad.tools.mathtools.difference_series.difference_series
      ~abjad.tools.mathtools.divide_number_by_ratio.divide_number_by_ratio
      ~abjad.tools.mathtools.divisors.divisors
      ~abjad.tools.mathtools.factors.factors
      ~abjad.tools.mathtools.fraction_to_proper_fraction.fraction_to_proper_fraction
      ~abjad.tools.mathtools.get_shared_numeric_sign.get_shared_numeric_sign
      ~abjad.tools.mathtools.greatest_common_divisor.greatest_common_divisor
      ~abjad.tools.mathtools.greatest_multiple_less_equal.greatest_multiple_less_equal
      ~abjad.tools.mathtools.greatest_power_of_two_less_equal.greatest_power_of_two_less_equal
      ~abjad.tools.mathtools.integer_equivalent_number_to_integer.integer_equivalent_number_to_integer
      ~abjad.tools.mathtools.integer_to_base_k_tuple.integer_to_base_k_tuple
      ~abjad.tools.mathtools.integer_to_binary_string.integer_to_binary_string
      ~abjad.tools.mathtools.is_assignable_integer.is_assignable_integer
      ~abjad.tools.mathtools.is_dotted_integer.is_dotted_integer
      ~abjad.tools.mathtools.is_integer_equivalent_expr.is_integer_equivalent_expr
      ~abjad.tools.mathtools.is_integer_equivalent_number.is_integer_equivalent_number
      ~abjad.tools.mathtools.is_negative_integer.is_negative_integer
      ~abjad.tools.mathtools.is_nonnegative_integer.is_nonnegative_integer
      ~abjad.tools.mathtools.is_nonnegative_integer_equivalent_number.is_nonnegative_integer_equivalent_number
      ~abjad.tools.mathtools.is_nonnegative_integer_power_of_two.is_nonnegative_integer_power_of_two
      ~abjad.tools.mathtools.is_positive_integer.is_positive_integer
      ~abjad.tools.mathtools.is_positive_integer_equivalent_number.is_positive_integer_equivalent_number
      ~abjad.tools.mathtools.is_positive_integer_power_of_two.is_positive_integer_power_of_two
      ~abjad.tools.mathtools.least_common_multiple.least_common_multiple
      ~abjad.tools.mathtools.least_multiple_greater_equal.least_multiple_greater_equal
      ~abjad.tools.mathtools.least_power_of_two_greater_equal.least_power_of_two_greater_equal
      ~abjad.tools.mathtools.next_integer_partition.next_integer_partition
      ~abjad.tools.mathtools.partition_integer_by_ratio.partition_integer_by_ratio
      ~abjad.tools.mathtools.partition_integer_into_canonic_parts.partition_integer_into_canonic_parts
      ~abjad.tools.mathtools.partition_integer_into_halves.partition_integer_into_halves
      ~abjad.tools.mathtools.partition_integer_into_parts_less_than_double.partition_integer_into_parts_less_than_double
      ~abjad.tools.mathtools.partition_integer_into_units.partition_integer_into_units
      ~abjad.tools.mathtools.remove_powers_of_two.remove_powers_of_two
      ~abjad.tools.mathtools.sign.sign
      ~abjad.tools.mathtools.weight.weight
      ~abjad.tools.mathtools.yield_all_compositions_of_integer.yield_all_compositions_of_integer
      ~abjad.tools.mathtools.yield_all_partitions_of_integer.yield_all_partitions_of_integer
      ~abjad.tools.mathtools.yield_nonreduced_fractions.yield_nonreduced_fractions
